==> haskell-http-conduit-2.2.3.1-20-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.2.3.1
id: http-conduit-2.2.3.1-DaYikPquclhEOWJkY0CEZG
key: http-conduit-2.2.3.1-DaYikPquclhEOWJkY0CEZG
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
    Network.HTTP.Simple
abi: 2ec3fa51c2899c80b7c1376c009392fd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.2.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.2.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-conduit-2.2.3.1
hs-libraries: HShttp-conduit-2.2.3.1-DaYikPquclhEOWJkY0CEZG
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-BpluvowJzclKWa0VheNANV
    http-client-tls-0.3.4.1-HCq1v0KzUVEAaMovFJK73q
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.2.3.1-23-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.2.3.1
id: http-conduit-2.2.3.1-FNNHiBVCfis7ewcrQUsAvf
key: http-conduit-2.2.3.1-FNNHiBVCfis7ewcrQUsAvf
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
    Network.HTTP.Simple
abi: 832c5e2f2a5756ba2c672457767b298a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.2.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.2.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-conduit-2.2.3.1
hs-libraries: HShttp-conduit-2.2.3.1-FNNHiBVCfis7ewcrQUsAvf
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-wVCkiPnh0GHIyvDsvtfzo
    http-client-tls-0.3.4.1-5Kt4eI2v9ko9acTDblvWzK
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
